//
// Simple error generator
//
// John Robinson, 1995, 1997.
//
// error infile outfile waitforbytes recip_of_error_rate
//
// Reads infile and copies waitforbytes bytes uncorrupted to outfile. (This
// is to simulate having strong error correction applied to the header of
// the file.) Then generates random bit errors at a rate
// 1/recip_of_error rate
// For example, running: error inpic outpic 50 10000 will produce an
// output picture with a simulated error rate of 1x10(E-5), except that the
// first 50 bytes will be error free.
//
#include "usage.h"
#include <fstream>
#include <time.h>
#include <stdlib.h>
using namespace std;
int main(int argc, char **argv) {
	usage("error infile outfile waitforbytes recip_of_rate");
	ifstream in(argv[1]);
	if (!in) {
		cerr << "Can't open " << argv[1] << endl;
		return -1;
		}
	ofstream out(argv[2]);
	if (!out)
		{
		cerr << "Can't open " << argv[2] << endl;
		return -1;
		}
	time_t now;
	time(&now);
	srand(now);
	int waitfor = atoi(argv[3]);
	int rate = atoi(argv[4]);
	int cnt = 0;
	unsigned char c;
	while(waitfor-- && !in.eof()) {
		// Copy the header without errors
		// in.get(c);
		c = in.get();
		out.put(c);
		}
	while(!in.eof()) {
		// in.get(c);
		c = in.get();
		for (int whichbit = 7; whichbit >= 0; whichbit--) {
			if (rand()%rate == 1)
			// True with probability 1/rate
				{
				c ^= (1<<whichbit);
				cnt++;
				}
			}
		out.put(c);
		}
	cerr << "Total number of errors = " << cnt << endl;
	return 0;
	}
