//
// Runlength encode a picture.
//
// John Robinson. January 1997.
//
// Simple algorithm assumes picture has two levels, 0 and 255. Assumes
// starts with run of black and codes its length (could be zero). Then
// codes white and black runs alternately.
#include <fstream>
#include "usage.h"
#include "picture.h"
int main(int argc, char *argv[])
	{
	usage("rlc inpic codefile");
	picture_of_int in(argv[1]);
	ofstream out(argv[2]);
	if (!out) {
		cerr << "Can't open " << argv[2] << endl;
		return -1;
		}
	// Write header to out, consisting simply of the picture size.
	out << in.nrows() << ' ' << in.ncols() << '\n';
	int prev = 0;	// Assume starts black
	int cnt = 0;	// Counts length of run
	for (int i = 0; i < in.nrows(); i++)
	for (int j = 0; j < in.ncols(); j++)
		// Scanning the picture in normal raster order
		{
		int temp = in[i][j];
		if (temp == prev) {
			if (++cnt == 256)
				{
				// First a run of 255 in this colour, then a
				// run of 0 in the other colour
				out << (unsigned char)255;
				out << (unsigned char)0;
				cnt = 1;
				}
			}
		else {
			prev = temp;
			out << (unsigned char)cnt;
			cnt = 1;
			}
		}
	out << (unsigned char)cnt;
	out.close();
	return 1;
	}

